==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/policy/v1/PodDisruptionBudgetStatus.scala <==
package io.k8s.api.policy.v1

import dev.hnaderi.k8s.utils._

/** PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system. */
final case class PodDisruptionBudgetStatus(
  disruptionsAllowed : Int,
  desiredHealthy : Int,
  expectedPods : Int,
  currentHealthy : Int,
  conditions : Option[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]] = None,
  disruptedPods : Option[Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]] = None,
  observedGeneration : Option[Int] = None
) {

  /** Returns a new data with disruptionsAllowed set to new value */
  def withDisruptionsAllowed(value: Int) : PodDisruptionBudgetStatus = copy(disruptionsAllowed = value)
  /** transforms disruptionsAllowed to result of function */
  def mapDisruptionsAllowed(f: Int => Int) : PodDisruptionBudgetStatus = copy(disruptionsAllowed = f(disruptionsAllowed))

  /** Returns a new data with desiredHealthy set to new value */
  def withDesiredHealthy(value: Int) : PodDisruptionBudgetStatus = copy(desiredHealthy = value)
  /** transforms desiredHealthy to result of function */
  def mapDesiredHealthy(f: Int => Int) : PodDisruptionBudgetStatus = copy(desiredHealthy = f(desiredHealthy))

  /** Returns a new data with expectedPods set to new value */
  def withExpectedPods(value: Int) : PodDisruptionBudgetStatus = copy(expectedPods = value)
  /** transforms expectedPods to result of function */
  def mapExpectedPods(f: Int => Int) : PodDisruptionBudgetStatus = copy(expectedPods = f(expectedPods))

  /** Returns a new data with currentHealthy set to new value */
  def withCurrentHealthy(value: Int) : PodDisruptionBudgetStatus = copy(currentHealthy = value)
  /** transforms currentHealthy to result of function */
  def mapCurrentHealthy(f: Int => Int) : PodDisruptionBudgetStatus = copy(currentHealthy = f(currentHealthy))

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : PodDisruptionBudgetStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.apimachinery.pkg.apis.meta.v1.Condition*) : PodDisruptionBudgetStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition] => Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : PodDisruptionBudgetStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with disruptedPods set to new value */
  def withDisruptedPods(value: Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]) : PodDisruptionBudgetStatus = copy(disruptedPods = Some(value))
  /** Adds new values to disruptedPods */
  def addDisruptedPods(newValues: (String, io.k8s.apimachinery.pkg.apis.meta.v1.Time)*) : PodDisruptionBudgetStatus = copy(disruptedPods = Some(disruptedPods.fold(newValues.toMap)(_ ++ newValues)))
  /** if disruptedPods has a value, transforms to the result of function*/
  def mapDisruptedPods(f: Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time] => Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]) : PodDisruptionBudgetStatus = copy(disruptedPods = disruptedPods.map(f))

  /** Returns a new data with observedGeneration set to new value */
  def withObservedGeneration(value: Int) : PodDisruptionBudgetStatus = copy(observedGeneration = Some(value))
  /** if observedGeneration has a value, transforms to the result of function*/
  def mapObservedGeneration(f: Int => Int) : PodDisruptionBudgetStatus = copy(observedGeneration = observedGeneration.map(f))
}

object PodDisruptionBudgetStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.policy.v1.PodDisruptionBudgetStatus, T] = new Encoder[io.k8s.api.policy.v1.PodDisruptionBudgetStatus, T] {
        def apply(o: io.k8s.api.policy.v1.PodDisruptionBudgetStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("disruptionsAllowed", o.disruptionsAllowed)
            .write("desiredHealthy", o.desiredHealthy)
            .write("expectedPods", o.expectedPods)
            .write("currentHealthy", o.currentHealthy)
            .write("conditions", o.conditions)
            .write("disruptedPods", o.disruptedPods)
            .write("observedGeneration", o.observedGeneration)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, PodDisruptionBudgetStatus] = new Decoder[T, PodDisruptionBudgetStatus] {
      def apply(t: T): Either[String, PodDisruptionBudgetStatus] = for {
          obj <- ObjectReader(t)
          disruptionsAllowed <- obj.read[Int]("disruptionsAllowed")
          desiredHealthy <- obj.read[Int]("desiredHealthy")
          expectedPods <- obj.read[Int]("expectedPods")
          currentHealthy <- obj.read[Int]("currentHealthy")
          conditions <- obj.readOpt[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]]("conditions")
          disruptedPods <- obj.readOpt[Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]]("disruptedPods")
          observedGeneration <- obj.readOpt[Int]("observedGeneration")
      } yield PodDisruptionBudgetStatus (
          disruptionsAllowed = disruptionsAllowed,
          desiredHealthy = desiredHealthy,
          expectedPods = expectedPods,
          currentHealthy = currentHealthy,
          conditions = conditions,
          disruptedPods = disruptedPods,
          observedGeneration = observedGeneration
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.0.1-sources.jar: io/k8s/api/policy/v1/PodDisruptionBudgetStatus.scala <==
package io.k8s.api.policy.v1


/** PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system. */
final case class PodDisruptionBudgetStatus(
  conditions : Option[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]] = None,
  disruptionsAllowed : Int,
  disruptedPods : Option[Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]] = None,
  desiredHealthy : Int,
  expectedPods : Int,
  observedGeneration : Option[Int] = None,
  currentHealthy : Int
) {
  def withConditions(value: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : PodDisruptionBudgetStatus = copy(conditions = Some(value))
  def addConditions(newValues: io.k8s.apimachinery.pkg.apis.meta.v1.Condition*) : PodDisruptionBudgetStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))

  def withDisruptionsAllowed(value: Int) : PodDisruptionBudgetStatus = copy(disruptionsAllowed = value)
  def withDisruptedPods(value: Map[String, io.k8s.apimachinery.pkg.apis.meta.v1.Time]) : PodDisruptionBudgetStatus = copy(disruptedPods = Some(value))
  def addDisruptedPods(newValues: (String, io.k8s.apimachinery.pkg.apis.meta.v1.Time)*) : PodDisruptionBudgetStatus = copy(disruptedPods = Some(disruptedPods.fold(newValues.toMap)(_ ++ newValues)))

  def withDesiredHealthy(value: Int) : PodDisruptionBudgetStatus = copy(desiredHealthy = value)
  def withExpectedPods(value: Int) : PodDisruptionBudgetStatus = copy(expectedPods = value)
  def withObservedGeneration(value: Int) : PodDisruptionBudgetStatus = copy(observedGeneration = Some(value))
  def withCurrentHealthy(value: Int) : PodDisruptionBudgetStatus = copy(currentHealthy = value)
}
